geowatch.tasks.cold.transfer\_features module
=============================================

.. automodule:: geowatch.tasks.cold.transfer_features
   :members:
   :undoc-members:
   :show-inheritance:
